=======
Credits
=======

Development Lead
----------------

- `Xiaokui Shu`_
- `Paul Coccoli`_

Contributors
------------

- `Raymund Lin`_

.. _Xiaokui Shu: https://github.com/subbyte
.. _Paul Coccoli: https://github.com/pcoccoli
.. _Raymund Lin: https://github.com/raymundl
